/*
 bridge.h - Bridge Interface for NXP JN516x Series

 Copyright (c) 2022 Sasapea's Lab. All right reserved.

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General
 Public License along with this library; if not, write to the
 Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 Boston, MA  02111-1307  USA
 */
#pragma once

#include <stdint.h>

class Bridge
{
  public:

    enum
    {
      TYPE_XMIT_STATUS = 0x10,
      TYPE_RETRANSMIT  = 0x40,
      TYPE_BROADCAST   = 0x80,
    };

    typedef struct __attribute__((packed))
    {
      uint8_t length;
      uint8_t type;
      uint8_t addrH;
      uint8_t addrL;
      uint8_t data[256 - 5];
      uint8_t csum;
    } packet_t;

    static
    uint8_t csum(const uint8_t *buf, uint8_t len)
    {
      uint8_t c = 0;
      while (len--)
        c ^= *buf++;
      return c;
    }
};
